ShardTimeoutError class

Thrown by ShardTester when an async wait exceeds its timeout.

Inheritance

Constructors

ShardTimeoutError(String message)
Creates a ShardTimeoutError with a human-readable message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The timeout failure message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited