ObservedChange<T> class
A single observed onChange event captured by MockShardObserver.
Constructors
-
ObservedChange(Shard<
T> shard, T previousState, T currentState) -
Creates an ObservedChange record.
const
Properties
- currentState → T
-
The state after the change.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- previousState → T
-
The state before the change.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
The shard whose state changed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited