ObservedError class
A single observed onError event captured by MockShardObserver.
Constructors
- ObservedError(Shard shard, Object error, [StackTrace? stackTrace])
-
Creates an ObservedError record.
const
Properties
- error → Object
-
The error object.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
The shard that reported the error.
final
- stackTrace → StackTrace?
-
The stack trace, if provided.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited